<?php

/*
 * Copyright by SoftCreatR Media.
 *
 * License: https://www.softcreatr.com/license-terms
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
 * AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
 * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 * OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS
 * IN THE SOFTWARE.
 *
 * The above copyright notice and this disclaimer notice shall be included in all
 * copies or substantial portions of the Software.
 */

namespace wcf\data\user\avatar;

use wcf\system\WCF;
use wcf\util\StringUtil;

use function filemtime;

class ScDefaultAvatar extends DefaultAvatar
{
    /**
     * @inheritDoc
     */
    public function getImageTag($size = null)
    {
        if (AVATAR_DEFAULT_TYPE !== 'custom' || !AVATAR_DEFAULT_IMAGE) {
            return parent::getImageTag($size);
        }

        if ($size === null) {
            $size = $this->size;
        }

        return '<img src="' . StringUtil::encodeHTML($this->getURL($size)) . '?v=' . filemtime(WCF_DIR . AVATAR_DEFAULT_IMAGE) . '" width="' . $size . '" height="' . $size . '" alt="" class="userAvatarImage" loading="lazy">';
    }

    /**
     * @inheritDoc
     */
    public function getURL($size = null)
    {
        if ($size === null) {
            $size = $this->size;
        }

        if (AVATAR_DEFAULT_TYPE !== 'custom' || !AVATAR_DEFAULT_IMAGE) {
            return parent::getURL($size);
        }

        return WCF::getPath() . AVATAR_DEFAULT_IMAGE;
    }
}
