<?php

/*
 * Copyright by SoftCreatR Media.
 *
 * License: https://www.softcreatr.com/license-terms
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
 * AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
 * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 * OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS
 * IN THE SOFTWARE.
 *
 * The above copyright notice and this disclaimer notice shall be included in all
 * copies or substantial portions of the Software.
 */

namespace wcf\system\upload;

use Exception;
use SoftCreatR\MimeDetector\MimeDetectorException;
use wcf\data\user\avatar\UserAvatar;
use wcf\util\MimeUtil;

use function getimagesize;
use function in_array;

class ScDefaultAvatarImageUploadFileValidationStrategy implements IUploadFileValidationStrategy
{
    /**
     * list of allowed file extensions
     *
     * @var string[]
     */
    public static $allowedExtensions = [
        'gif',
        'jpg',
        'png',
        'svg'
    ];

    /**
     * @inheritDoc
     *
     * @throws MimeDetectorException
     */
    public function validate(UploadFile $uploadFile)
    {
        if ($uploadFile->getErrorCode() !== 0) {
            $uploadFile->setValidationErrorType('uploadFailed');

            return false;
        }

        $fileExtension = MimeUtil::getFileExtension($uploadFile->getLocation());

        // validate file extension
        if (!in_array($fileExtension, self::$allowedExtensions, true)) {
            $uploadFile->setValidationErrorType('noImage');

            return false;
        }

        // check image data
        if ($fileExtension !== 'svg' && $uploadFile->getImageData() === null) {
            $uploadFile->setValidationErrorType('uploadFailed');

            return false;
        }

        // check image size
        if ($fileExtension !== 'svg') {
            try {
                $imageData = getimagesize($uploadFile->getLocation());
                if ($imageData[0] < UserAvatar::AVATAR_SIZE || $imageData[1] < UserAvatar::AVATAR_SIZE) {
                    $uploadFile->setValidationErrorType('tooSmall');

                    return false;
                }
            } catch (Exception $e) {
                $uploadFile->setValidationErrorType('badImage');

                return false;
            }
        }

        return true;
    }
}
